@@ -25,18 +25,18 @@ class ISubscribeForm(Interface):
     """ define field for channel subscription """
 
     email = schema.Email(
-        title=_(u'subscribe_user', default=u'Subscription Mail'),
+        title=_(u"subscribe_user", default=u"Subscription Mail"),
         description=_(
-            u'subscribe_user_description',
-            default=u'Mail for subscribe to a channel',
+            u"subscribe_user_description",
+            default=u"Mail for subscribe to a channel",
         ),
         required=True,
     )
 
     directives.widget(captcha=ReCaptchaFieldWidget)
     captcha = schema.TextLine(
-        title=_(u'Captcha', default=u'Controllo di sicurezza'),
-        description=u'',
+        title=_(u"Captcha", default=u"Controllo di sicurezza"),
+        description=u"",
         required=False,
     )
 
@@ -63,39 +63,41 @@ class SubscribeForm(AutoExtensibleForm, form.Form):
     def update(self):
         super(SubscribeForm, self).update()
 
-    @button.buttonAndHandler(_(u'subscribe_submit_label', default=u'Subscribe'))
+    @button.buttonAndHandler(
+        _(u"subscribe_submit_label", default=u"Subscribe")
+    )
     def handleSave(self, action):
         status = UNHANDLED
         data, errors = self.extractData()
 
         # recaptcha
         captcha = getMultiAdapter(
-            (aq_inner(self.context), self.request), name='recaptcha'
+            (aq_inner(self.context), self.request), name="recaptcha"
         )
         if errors:
             self.status = self.formErrorsMessage
             if self.status:
                 self.status = (
-                    u'Indirizzo email non inserito o non '
-                    + 'valido, oppure controllo di sicurezza non '
-                    + 'inserito.'
+                    u"Indirizzo email non inserito o non " +
+                    "valido, oppure controllo di sicurezza non " +
+                    "inserito."
                 )
             return
         if not captcha.verify():
             api.portal.show_message(
                 message=_(
-                    u'message_wrong_captcha',
-                    default=u'Captcha non inserito correttamente.',
+                    u"message_wrong_captcha",
+                    default=u"Captcha non inserito correttamente.",
                 ),
                 request=self.request,
-                type=u'error',
+                type=u"error",
             )
             return
 
         email = None
-        if self.context.portal_type == 'Channel':
+        if self.context.portal_type == "Channel":
             channel = self.context.id_channel
-        email = data['email']
+        email = data["email"]
 
         if self.context.is_subscribable:
             api_channel = getUtility(IChannelUtility)
@@ -108,82 +110,82 @@ class SubscribeForm(AutoExtensibleForm, form.Form):
 
             # mando mail di conferma
             url = self.context.absolute_url()
-            url += '/confirmaction?secret=' + secret
-            url += '&_authenticator=' + token
-            url += '&action=subscribe'
+            url += "/confirmaction?secret=" + secret
+            url += "&_authenticator=" + token
+            url += "&action=subscribe"
 
             mail_template = self.context.restrictedTraverse(
-                '@@activeuser_template'
+                "@@activeuser_template"
             )
 
             parameters = {
-                'title': self.context.title,
-                'header': self.context.header,
-                'footer': self.context.footer,
-                'style': self.context.css_style,
-                'activationUrl': url,
-                'portal_name': get_site_title(),
+                "title": self.context.title,
+                "header": self.context.header,
+                "footer": self.context.footer,
+                "style": self.context.css_style,
+                "activationUrl": url,
+                "portal_name": get_site_title(),
             }
 
             mail_text = mail_template(**parameters)
 
             portal = api.portal.get()
             mail_text = portal.portal_transforms.convertTo(
-                'text/mail', mail_text
+                "text/mail", mail_text
             )
 
             response_email = None
             if self.context.sender_email:
                 response_email = self.context.sender_email
             else:
-                response_email = u'noreply@rer.it'
+                response_email = u"noreply@rer.it"
 
-            mailHost = api.portal.get_tool(name='MailHost')
+            mailHost = api.portal.get_tool(name="MailHost")
             mailHost.send(
                 mail_text.getData(),
                 mto=email,
                 mfrom=response_email,
-                subject='Conferma la tua iscrizione alla Newsletter '
-                + self.context.title
-                + ' del portale '
-                + get_site_title(),
-                charset='utf-8',
-                msg_type='text/html',
+                subject="Conferma la tua iscrizione alla Newsletter " +
+                self.context.title +
+                " del portale " +
+                get_site_title(),
+                charset="utf-8",
+                msg_type="text/html",
                 immediate=True,
             )
 
             api.portal.show_message(
                 message=_(
-                    u'status_user_subscribed',
-                    default=u'Riceverai una e-mail per confermare '
-                    'l\'iscrizione alla newsletter.',
+                    u"status_user_subscribed",
+                    default=u"Riceverai una e-mail per confermare "
+                    "l'iscrizione alla newsletter.",
                 ),
                 request=self.request,
-                type=u'info',
+                type=u"info",
             )
 
         else:
             if status == 2:
-                logger.exception('user already subscribed')
+                logger.exception("user already subscribed")
                 api.portal.show_message(
                     message=_(
-                        u'user_already_subscribed',
-                        default=u'Sei già iscritto a questa newsletter, '
-                        'oppure non hai ancora'
-                        ' confermato l\'iscrizione.',
+                        u"user_already_subscribed",
+                        default=u"Sei già iscritto a questa newsletter, "
+                        "oppure non hai ancora"
+                        " confermato l'iscrizione.",
                     ),
                     request=self.request,
-                    type=u'error',
+                    type=u"error",
                 )
             else:
-                logger.exception('unhandled error subscribe user')
+                logger.exception("unhandled error subscribe user")
                 api.portal.show_message(
-                    message=u'Problems...{0}'.format(status),
+                    message=u"Problems...{0}".format(status),
                     request=self.request,
-                    type=u'error',
+                    type=u"error",
                 )
 
 
 subscribe_view = wrap_form(
-    SubscribeForm, index=ViewPageTemplateFile('templates/subscribechannel.pt')
+    SubscribeForm, index=ViewPageTemplateFile("templates/subscribechannel.pt")
 )
