@@ -11,17 +11,13 @@ from rer.newsletter.utility.channel import IChannelUtility
 from rer.newsletter.utility.channel import OK
 from rer.newsletter.utils import addToHistory
 from rer.newsletter.utils import get_site_title
+from six.moves.urllib.parse import urlencode
 from z3c.form import button
 from z3c.form import form
 from zope.annotation.interfaces import IAnnotations
 from zope.component import getUtility
 from zope.component import queryUtility
 
-try:
-    import urlencode
-except ImportError:
-    from urllib.parse import urlencode
-
 
 try:
     from collective.taskqueue.interfaces import ITaskQueue
